#include "options.h"
#include "ui_options.h"

Options::Options(QWidget *parent) :
    ui(new Ui::Options)
{
    ui->setupUi(this);
}

Options::~Options()
{
    delete ui;
}

void Options::on_closeButton_clicked()
{
    this->closeButtonClicked();
    this->close();
}

void Options::on_cancelPushButton_clicked()
{
    this->close();
}

void Options::on_clearButton_clicked()
{
    this->clearCurrentClicked();
    this->close();
}

void Options::on_removePlaylists_clicked()
{
    this->removePlaylistsButtonClicked();
    this->close();
}
